@@ -14,6 +14,7 @@ from toolkit_w.internal.token_json import UserToken
 from toolkit_w.internal.vars_global import ProblemType, TargetMetric, FeatureType
 from toolkit_w.internal.vars_global import InterpretabilityLevel as Interpt
 import toolkit_w as my_toolkit
+from ast import literal_eval
 
 logging.getLogger().setLevel(logging.INFO)
 logging.basicConfig(level=logging.INFO, format='%(levelname)s:%(message)s')
@@ -428,7 +429,7 @@ class MyWhatify:
         with allure.step(' '.join(['creating wisdom name:', str(name), 'template_id:', str(template_id), 'user_input:',
                                    str(user_input)])):
             wisdom_id = my_toolkit.Wisdom.create_wisdom(name=name, user_id=user_id if user_id else cls.get_user_id(),
-                                                        template_id=template_id, user_input=user_input,
+                                                        template_id=template_id, user_input=literal_eval(str(user_input)),
                                                         api_key=user_token)
         return wisdom_id
 
